Oracle NoSQL Database Cloud Service Python SDK
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

=====
About
=====

This is the Python SDK for Oracle NoSQL Database Cloud Service. Python 2.7+ and 3.5+ are supported.

This project is open source and maintained by Oracle Corp. The home page for the
project is
`here <https://nosql-python-sdk.readthedocs.io/en/latest/index.html>`_

============
Installation
============

The SDK can be installed using pip.
::

    pip install borneo

See `the installation guide <https://nosql-python-sdk .readthedocs.io/en/latest/installation.html>`_ for additional requirements and and alternative install methods.

========
Examples
========

Examples can be found `on GitHub <https://github.com/oracle/nosql-python-sdk/tree/master/examples>`_.

Examples include simple, standalone programs. They include comments
about how they can be configured and run.

=============
Documentation
=============

The `documentation <https://nosql-python-sdk.readthedocs.io/en/latest>`_ has
information on using the SDK as well as an `api reference <https://nosql-python-sdk.readthedocs.io/en/latest/api.html>`_ describing the classes.

===========
Development
===========

The `development readme <https://github.com/oracle/nosql-python-sdk/blob/master/README-DEV.rst>`_ has information about running tests and
examples, building the documentation, and other development activities.

=======
Changes
=======

See the `Changelog <https://github.com/oracle/nosql-python-sdk/blob/master/CHANGELOG.rst>`_.

============
Contributing
============

The nosql-python-sdk is an open source project. See
`Contributing <https://github.com/oracle/nosql-python-sdk/blob/master/CONTRIBUTING.rst>`_
for information on how to contribute to the project.

=======
License
=======

Copyright (C) 2018, 2019 Oracle and/or its affiliates. All rights reserved.

This SDK is licensed under the Universal Permissive License 1.0. See
`LICENSE <https://github.com/oracle/nosql-python-sdk/blob/master/LICENSE.txt>`_ for details
